@@ -286,7 +286,8 @@ def send_telegram_message(telegram_active, telegram_program, telegram_recipient_
 
 def get_mobile_device_presence(_wifi_devices_dict, _router_ip_address, _router_password,
                                _bluetooth_devices_dict,
-                               _scan_for_device_type):
+                               _scan_for_device_type,
+                               _calling_software):
     """
     Evaluates whether a bluetooth of WiFi device can be detected.
     :param: _wifi_devices_dict: dict, contains the wifi devices name and Mac address
@@ -294,6 +295,7 @@ def get_mobile_device_presence(_wifi_devices_dict, _router_ip_address, _router_p
     :param: _router_password: string, contains the routers password
     :param: _bluetooth_devices_dict: dict, contains the bluetooth devices name and Mac address
     :param: _scan_for_device_type: string, contains the scan type "bluetooth" or "WiFi" or "both"
+    :param: _calling_software: string, contains the which software is calling this function "rha" or "pir"
     :returns: bool, device in dictionaries _wifi_devices_dict or  _bluetooth_devices_dict are present
     """
 
@@ -321,29 +323,39 @@ def get_mobile_device_presence(_wifi_devices_dict, _router_ip_address, _router_p
         return None, False
 
     def mobile_device_presence():
+        bluetooth_key, bluetooth_bool = scan_bluetooth()
+        wifi_key, wifi_bool = scan_wifi()
         if _scan_for_device_type == "bluetooth":
-            return scan_bluetooth()
+            if _calling_software == "pir":
+                return bluetooth_key, bluetooth_bool
+            elif _calling_software == "rha":
+                return bluetooth_bool
         elif _scan_for_device_type == "wifi":
-            return scan_wifi()
+            if _calling_software == "pir":
+                return wifi_key, wifi_bool
+            elif _calling_software == "rha":
+                return wifi_bool
         elif _scan_for_device_type == "both":
-            bluetooth_key, bluetooth_bool = scan_bluetooth()
-            wifi_key, wifi_bool = scan_wifi()
-
             if bluetooth_key is None and wifi_key is None:
                 module_logger.info("def 'mobile_device_presence' returns: None and False")
-                return None, False
-            elif bluetooth_key is not None and wifi_key is not None:
-                module_logger.info("def 'mobile_device_presence' returns: '" + bluetooth_key + "' and '" +
-                                   str(bluetooth_bool) + "'")
-                return bluetooth_key, bluetooth_bool
+                if _calling_software == "pir":
+                    return None, False
+                elif _calling_software == "rha":
+                    return False
             elif bluetooth_key is None and wifi_key is not None:
                 module_logger.info("def 'mobile_device_presence' returns: '" + wifi_key + "' and '" +
                                    str(wifi_bool) + "'")
-                return wifi_key, wifi_bool
-            elif bluetooth_key is not None and wifi_key is None:
+                if _calling_software == "pir":
+                    return wifi_key, wifi_bool
+                elif _calling_software == "rha":
+                    return wifi_bool
+            elif bluetooth_key is not None:
                 module_logger.info("def 'mobile_device_presence' returns: '" + bluetooth_key + "' and '" +
                                    str(bluetooth_bool) + "'")
-                return bluetooth_key, bluetooth_bool
+                if _calling_software == "pir":
+                    return bluetooth_key, bluetooth_bool
+                elif _calling_software == "rha":
+                    return bluetooth_bool
 
     return mobile_device_presence
 
